@@ -1,5 +1,4 @@
 # simpler import as described in the readme
-from restcountries.base import RestCountryApi
 from restcountries.base import RestCountryApiV2
 
-__version__ = "0.3"
+__version__ = "2.0.0"
